==> 0.1.0.tar.gz: test/src/async_disposable_test.dart <==
part of disposable_test;

async_disposable_tests() {

  group('-async_disposable- should', () {

    test('complete future on dispose', () {
      // Arrange
      bool disposed = false;
      IAsyncDisposable disposable = new AsyncDisposable();
      disposable.future.then((_) => disposed = true);

      // Act
      disposable.dispose();

      // Assert
      expect(disposable.isDisposed, true);
      expect(disposed, true);
    });

    test('complete future with value when using disposeWith', () {
      // Arrange
      var value;
      IAsyncDisposable disposable = new AsyncDisposable();
      disposable.future
        .then((v) => value = v);

      // Act
      disposable.disposeWith('stuff');

      // Assert
      expect(disposable.isDisposed, true);
      expect(value, 'stuff');
    });

    test('not complete future but should dispose and carry error data in completeError callback when using disposeError', () {
      // Arrange
      var futureCalled = false;
      var error;
      IAsyncDisposable disposable = new AsyncDisposable();
      disposable.future
        .then((_) => futureCalled = true)
        .catchError((ex) => error = ex);

      // Act
      disposable.disposeError('error');

      // Assert
      expect(disposable.isDisposed, true);
      expect(futureCalled, false);
      expect(error, 'error');
    });

    test('complete with value when disposeWith is called', () {
      // Arrange
      var disposeCalled = false;
      var errorCalled = false;
      var futureCalled = false;
      var error;
      IAsyncDisposable disposable = new AsyncDisposable(() => disposeCalled = true);
      disposable.future
        .then((value) {
          expect(value, 10);
          futureCalled = true;
        },
          onError: (ex) => error = ex)
        .then(expectAsync1((_) {
          // Assert
          expect(disposable.isDisposed, true);
          expect(futureCalled, true);
        }));

      // Act
      try {
        disposable.disposeWith(10);
      } catch(ex) {
        expect(ex, 'dispose error');
      }
    });

    test('complete with error if super throws exception on dispose', () {
      // Arrange
      var errorCalled = false;
      var futureCalled = false;
      var error;
      IAsyncDisposable disposable = new AsyncDisposable(() => throw 'dispose error');
      disposable.future
        .then((_) => futureCalled = true,
          onError: (ex) => error = ex)
        .then(expectAsync1((_) {
          // Assert
          expect(disposable.isDisposed, true);
          expect(futureCalled, false);
          expect(error, 'dispose error');
        }));

      // Act
      try {
        disposable.dispose();
      } catch(ex) {
        expect(ex, 'dispose error');
      }
    });

    test('complete with error if super throws exception on disposeWith', () {
      // Arrange
      var errorCalled = false;
      var futureCalled = false;
      var error;
      IAsyncDisposable disposable = new AsyncDisposable(() => throw 'dispose error');
      disposable.future
      .then((_) => futureCalled = true,
      onError: (ex) => error = ex)
      .then(expectAsync1((_) {
        // Assert
        expect(disposable.isDisposed, true);
        expect(futureCalled, false);
        expect(error, 'dispose error');
      }));

      // Act
      try {
        disposable.disposeWith(10);
      } catch(ex) {
        expect(ex, 'dispose error');
      }
    });

    test('complete with error if super throws exception on disposeError', () {
      // Arrange
      var errorCalled = false;
      var futureCalled = false;
      var error;
      IAsyncDisposable disposable = new AsyncDisposable(() => throw 'dispose error');
      disposable.future
      .then((_) => futureCalled = true,
      onError: (ex) => error = ex)
      .then(expectAsync1((_) {
        // Assert
        expect(disposable.isDisposed, true);
        expect(futureCalled, false);
        expect(error, 'dispose error');
      }));

      // Act
      try {
        disposable.disposeError(10);
      } catch(ex) {
        expect(ex, 'dispose error');
      }
    });

  });

}

==> 0.1.2.tar.gz: test/src/async_disposable_test.dart <==
part of disposable_test;

async_disposable_tests() {

  group('-async_disposable- should', () {

    test('complete future on dispose', () {
      // Arrange
      bool disposed = false;
      IAsyncDisposable disposable = new AsyncDisposable();
      //disposable.future.then((_) {
      disposable.future.then(expectAsync1((_) {
        disposed = true;

        // Assert
        expect(disposable.isDisposed, true);
        expect(disposed, true);
      }));

      // Act
      disposable.dispose();
    });

    test('complete future with value when using disposeWith', () {
      // Arrange
      var value;
      IAsyncDisposable disposable = new AsyncDisposable();
      //disposable.future
      //  .then((v) => value = v);
      disposable.future
        .then(expectAsync1((value) {
          // Assert
          expect(disposable.isDisposed, true);
          expect(value, 'stuff');
        }));

      // Act
      disposable.disposeWith('stuff');
    });

    test('not complete future but should dispose and carry error data in completeError callback when using disposeError', () {
      // Arrange
      var futureCalled = false;
      var error;
      IAsyncDisposable disposable = new AsyncDisposable();
      disposable.future
        .then(expectAsync1((_) {
           futureCalled = true;
           expect(false, true);
        }))
        .catchError(expectAsync1((error) {
          // Assert
          expect(disposable.isDisposed, true);
          expect(futureCalled, false);
          expect(error, 'error');
        }));

      // Act
      disposable.disposeError('error');

      // Assert
      //expect(disposable.isDisposed, true);
      //expect(futureCalled, false);
      //expect(error, 'error');
    });

    test('complete with value when disposeWith is called', () {
      // Arrange
      var disposeCalled = false;
      var errorCalled = false;
      var futureCalled = false;
      var error;
      IAsyncDisposable disposable = new AsyncDisposable(() => disposeCalled = true);
      disposable.future
        .then((value) {
          expect(value, 10);
          futureCalled = true;
        },
          onError: (ex) => error = ex)
        .then(expectAsync1((_) {
          // Assert
          expect(disposable.isDisposed, true);
          expect(futureCalled, true);
        }));

      // Act
      try {
        disposable.disposeWith(10);
      } catch(ex) {
        expect(ex, 'dispose error');
      }
    });

    test('complete with error if super throws exception on dispose', () {
      // Arrange
      var errorCalled = false;
      var futureCalled = false;
      var error;
      IAsyncDisposable disposable = new AsyncDisposable(() => throw 'dispose error');
      disposable.future
        .then((_) => futureCalled = true,
          onError: (ex) => error = ex)
        .then(expectAsync1((_) {
          // Assert
          expect(disposable.isDisposed, true);
          expect(futureCalled, false);
          expect(error, 'dispose error');
        }));

      // Act
      try {
        disposable.dispose();
      } catch(ex) {
        expect(ex, 'dispose error');
      }
    });

    test('complete with error if super throws exception on disposeWith', () {
      // Arrange
      var errorCalled = false;
      var futureCalled = false;
      var error;
      IAsyncDisposable disposable = new AsyncDisposable(() => throw 'dispose error');
      disposable.future
      .then((_) => futureCalled = true,
      onError: (ex) => error = ex)
      .then(expectAsync1((_) {
        // Assert
        expect(disposable.isDisposed, true);
        expect(futureCalled, false);
        expect(error, 'dispose error');
      }));

      // Act
      try {
        disposable.disposeWith(10);
      } catch(ex) {
        expect(ex, 'dispose error');
      }
    });

    test('complete with error if super throws exception on disposeError', () {
      // Arrange
      var errorCalled = false;
      var futureCalled = false;
      var error;
      IAsyncDisposable disposable = new AsyncDisposable(() => throw 'dispose error');
      disposable.future
      .then((_) => futureCalled = true,
      onError: (ex) => error = ex)
      .then(expectAsync1((_) {
        // Assert
        expect(disposable.isDisposed, true);
        expect(futureCalled, false);
        expect(error, 'dispose error');
      }));

      // Act
      try {
        disposable.disposeError(10);
      } catch(ex) {
        expect(ex, 'dispose error');
      }
    });

  });

}
